Crate marine_wasm_backend_traits

Crate marine_wasm_backend_traits 

Re-exports

pub use prelude::*;

Modules

caller
errors
exports
function
impl_utils
Helper functions for backend implementations.
imports
instance
macros
module
prelude
store
wasi
wtype

Macros

impl_for_each_function_signature
Copypasted from Wasmtime. A helper macros for implementing anything for 0-16 generic parameters. The expected argument signature is this:
replace_with

Structs

DelayedContextLifetime
This struct is a helper, that allows passing <WB as WasmBackend>::ContextMut as template parameter, but not specify a lifetime. Any local lifetime can be used instead.

Traits

WasmBackend
A core trait for any backend. It serves two purposes: